@@ -1,11 +1,12 @@
 package touch
 
 import (
-	"fmt"
+	jsoniter "github.com/json-iterator/go"
 	"github.com/v2rayA/v2rayA/db/configure"
+	"github.com/v2rayA/v2rayA/pkg/util/log"
 	"net"
 	"net/url"
-	"strings"
+	"strconv"
 	"time"
 )
 
@@ -14,11 +15,11 @@ Touch是树型结构的前后端通信形式，其结构设计和前端统一。
 */
 type SubscriptionStatus string
 type Touch struct {
-	Servers          []TouchServer    `json:"servers"`
-	Subscriptions    []Subscription   `json:"subscriptions"`
+	Servers          []Server           `json:"servers"`
+	Subscriptions    []Subscription     `json:"subscriptions"`
 	ConnectedServers []*configure.Which `json:"connectedServer"` //冗余一个信息，方便查找
 }
-type TouchServer struct {
+type Server struct {
 	ID          int                 `json:"id"`
 	TYPE        configure.TouchType `json:"_type"`
 	Name        string              `json:"name"`
@@ -33,66 +34,55 @@ type Subscription struct {
 	Host    string              `json:"host"`
 	Status  SubscriptionStatus  `json:"status"`
 	Info    string              `json:"info"`
-	Servers []TouchServer       `json:"servers"`
+	Servers []Server            `json:"servers"`
 }
 
 func NewUpdateStatus() SubscriptionStatus {
 	return SubscriptionStatus(time.Now().Local().Format("2006-1-2 15:04:05"))
 }
 
-/* 将[]TouchServerRaw映射到[]TouchServer */
-func serverRawsToServers(rss []configure.ServerRaw) (ts []TouchServer) {
-	ts = make([]TouchServer, len(rss))
+/* Mapping []TouchServerRaw to []Server */
+func serverRawsToServers(rss []configure.ServerRawV2) (ts []Server) {
+	ts = make([]Server, len(rss))
 	for i, v := range rss {
-		if v.VmessInfo.Protocol == "" {
-			v.VmessInfo.Protocol = "vmess"
-		}
-		protocol := strings.ToUpper(v.VmessInfo.Protocol)
-		var protoToShow string
-		switch v.VmessInfo.Protocol {
-		case "", "vmess", "vless":
-			if v.VmessInfo.TLS != "" && v.VmessInfo.TLS != "none" {
-				protoToShow = fmt.Sprintf("%v(%v+%v)", protocol, v.VmessInfo.Net, v.VmessInfo.TLS)
-			} else {
-				protoToShow = fmt.Sprintf("%v(%v)", protocol, v.VmessInfo.Net)
-			}
-		case "ss", "shadowsocks":
-			if v.VmessInfo.Type != "" {
-				protoToShow = fmt.Sprintf("%v(%v+%v)", protocol, v.VmessInfo.Net, v.VmessInfo.Type)
-			} else {
-				protoToShow = fmt.Sprintf("%v(%v)", protocol, v.VmessInfo.Net)
-			}
-		case "ssr", "shadowsocksr":
-			protoToShow = fmt.Sprintf("%v(%v)", protocol, v.VmessInfo.Type)
-		default:
-			protoToShow = protocol
-		}
 		var address string
-		if v.VmessInfo.Port == "" {
-			address = v.VmessInfo.Add
+		if v.ServerObj.GetPort() == 0 {
+			address = v.ServerObj.GetHostname()
 		} else {
-			address = net.JoinHostPort(v.VmessInfo.Add, v.VmessInfo.Port)
+			address = net.JoinHostPort(v.ServerObj.GetHostname(), strconv.Itoa(v.ServerObj.GetPort()))
 		}
-		ts[i] = TouchServer{
+		ts[i] = Server{
 			ID:          i + 1,
-			Name:        v.VmessInfo.Ps,
+			Name:        v.ServerObj.GetName(),
 			Address:     address,
-			Net:         protoToShow,
+			Net:         v.ServerObj.ProtoToShow(),
 			PingLatency: v.Latency,
 		}
 	}
 	return
 }
 
-/* 根据Configure创建一个Touch */
+// GenerateTouch generates a touch from database
 func GenerateTouch() (t Touch) {
-	t.Servers = serverRawsToServers(configure.GetServers())
-	subscriptions := configure.GetSubscriptions()
+	t.Servers = serverRawsToServers(configure.GetServersV2())
+	subscriptions := configure.GetSubscriptionsV2()
 	t.Subscriptions = make([]Subscription, len(subscriptions))
 	for i, v := range subscriptions {
 		u, err := url.Parse(v.Address)
 		if err != nil {
-			continue
+			// it may is OOCv1
+			tmp := make(map[string]string)
+			_ = jsoniter.Unmarshal([]byte(v.Address), &tmp)
+			if addr, ok := tmp["baseUrl"]; !ok {
+				log.Warn("%v", err)
+				continue
+			} else {
+				u, err = url.Parse(addr)
+				if err != nil {
+					log.Warn("%v", err)
+					continue
+				}
+			}
 		}
 		t.Subscriptions[i] = Subscription{
 			Remarks: v.Remarks,
