@@ -49,13 +49,19 @@ type Template struct {
 	Observatory *coreObj.Observatory `json:"observatory,omitempty"`
 	API         *coreObj.APIObject   `json:"api,omitempty"`
 
-	Variant      where.Variant      `json:"-"`
-	CoreVersion  string             `json:"-"`
-	Plugins      []plugin.Server    `json:"-"`
-	OutboundTags []string           `json:"-"`
-	ApiCloses    []func()           `json:"-"`
-	ApiPort      int                `json:"-"`
-	Setting      *configure.Setting `json:"-"`
+	Variant               where.Variant       `json:"-"`
+	CoreVersion           string              `json:"-"`
+	Plugins               []plugin.Server     `json:"-"`
+	OutboundTags          []string            `json:"-"`
+	ApiCloses             []func()            `json:"-"`
+	ApiPort               int                 `json:"-"`
+	Setting               *configure.Setting  `json:"-"`
+	PluginManagerInfoList []PluginManagerInfo `json:"-"`
+}
+
+type PluginManagerInfo struct {
+	Link string
+	Port int
 }
 
 func (t *Template) Close() error {
@@ -371,14 +377,18 @@ func (t *Template) setDNS(outbounds []serverInfo, supportUDP map[string]bool) (r
 	}
 	// hard code for SNI problem like apple pushing
 	t.DNS.Hosts = make(coreObj.Hosts)
-	t.DNS.Hosts["courier.push.apple.com"] = []string{"1-courier.push.apple.com"}
+	if service.CheckHostsListSupported() == nil {
+		t.DNS.Hosts["courier.push.apple.com"] = []string{"1-courier.push.apple.com"}
+	} else {
+		t.DNS.Hosts["courier.push.apple.com"] = "1-courier.push.apple.com"
+	}
 
 	// deduplicate
 	strRouting := make([]string, 0, len(routing))
 	for _, r := range routing {
 		b, err := jsoniter.Marshal(r)
 		if err != nil {
-			log.Fatal("%v", err)
+			return nil, fmt.Errorf("jsoniter.Marshal: %v", err)
 		}
 		strRouting = append(strRouting, string(b))
 	}
@@ -387,7 +397,7 @@ func (t *Template) setDNS(outbounds []serverInfo, supportUDP map[string]bool) (r
 	for _, sr := range strRouting {
 		var r coreObj.RoutingRule
 		if err := jsoniter.Unmarshal([]byte(sr), &r); err != nil {
-			log.Fatal("%v: %v", err, sr)
+			return nil, fmt.Errorf("jsoniter.Unmarshal: RoutingRule: %v", err)
 		}
 		routing = append(routing, r)
 	}
@@ -558,7 +568,17 @@ func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds
 					Domain:      []string{"geosite:geolocation-!cn"},
 				})
 		}
+
 		t.Routing.Rules = append(t.Routing.Rules,
+			coreObj.RoutingRule{
+				Type:        "field",
+				OutboundTag: firstOutboundTag,
+				InboundTag:  deepcopy.Copy(inbounds).([]string),
+				// From: https://github.com/Loyalsoldier/geoip/blob/release/text/telegram.txt
+				IP: []string{"91.105.192.0/23", "91.108.4.0/22", "91.108.8.0/21", "91.108.16.0/21", "91.108.56.0/22",
+					"95.161.64.0/20", "149.154.160.0/20", "185.76.151.0/24", "2001:67c:4e8::/48", "2001:b28:f23c::/47",
+					"2001:b28:f23f::/48", "2a0a:f280:203::/48"},
+			},
 			coreObj.RoutingRule{
 				Type:        "field",
 				OutboundTag: "direct",
@@ -1247,9 +1267,9 @@ func (t *Template) resolveOutbounds(
 			usedByBalancer     bool
 			balancerPluginPort int
 		)
-		// a vmessInfo(server template) may is used by multiple serverInfos(a connected server)
+		// an vmessInfo(server template) may be used by multiple serverInfos(a connected server)
 
-		// outbound name is not just v2ray outbound tag, it may is a balancer
+		// outbound name is not just v2ray outbound tag, it may be a balancer
 		type balancer struct {
 			name       string
 			serverInfo *serverInfo
@@ -1282,6 +1302,12 @@ func (t *Template) resolveOutbounds(
 					return nil, nil, err
 				}
 				extraOutbounds = append(extraOutbounds, c.ExtraOutbounds...)
+				if c.PluginManagerServerLink != "" {
+					t.PluginManagerInfoList = append(t.PluginManagerInfoList, PluginManagerInfo{
+						Link: c.PluginManagerServerLink,
+						Port: sInfo.PluginPort,
+					})
+				}
 				var s plugin.Server
 				if len(c.PluginChain) > 0 {
 					s, err = plugin.ServerFromChain(c.PluginChain)
@@ -1315,7 +1341,12 @@ func (t *Template) resolveOutbounds(
 			for _, v := range balancers {
 				c.CoreOutbound.Balancers = append(c.CoreOutbound.Balancers, v.name)
 			}
-
+			if c.PluginManagerServerLink != "" {
+				t.PluginManagerInfoList = append(t.PluginManagerInfoList, PluginManagerInfo{
+					Link: c.PluginManagerServerLink,
+					Port: balancerPluginPort,
+				})
+			}
 			// we use the lowest serverInfo index as the order weight of the balancer outbound
 			weight := -1
 			for _, v := range balancers {
@@ -1761,6 +1792,12 @@ func (t *Template) InsertMappingOutbound(o serverObj.ServerObj, inboundPort stri
 			t.Plugins = append(t.Plugins, server)
 		}
 	}
+	if c.PluginManagerServerLink != "" {
+		t.PluginManagerInfoList = append(t.PluginManagerInfoList, PluginManagerInfo{
+			Link: c.PluginManagerServerLink,
+			Port: pluginPort,
+		})
+	}
 	var mark = 0x80
 	t.checkAndSetMark(&c.CoreOutbound, mark)
 	t.Outbounds = append(t.Outbounds, c.CoreOutbound)
