@@ -60,7 +60,7 @@ func Disconnect(which configure.Which, clearOutbound bool) (err error) {
 func checkAssetsExist(setting *configure.Setting) error {
 	//FIXME: non-fully check
 	if setting.RulePortMode == configure.GfwlistMode || setting.Transparent == configure.TransparentGfwlist {
-		if !asset.LoyalsoldierSiteDatExists() {
+		if !asset.DoesV2rayAssetExist("LoyalsoldierSite.dat") {
 			return fmt.Errorf("GFWList file not exists. Try updating GFWList please")
 		}
 	}
